from typing import List

import mlflow


def find_run(experiment_id: str, run_name: str) -> List[str]:
    runs = mlflow.search_runs(experiment_ids=[experiment_id])

    matching_runs = runs[
        runs["tags.mlflow.runName"].str.contains(run_name, na=False)
    ]

    return matching_runs["run_id"].tolist()



import os
from typing import Optional

import click
from mlflow.cli import cli

from mlflow.nemo.search import find_run


@cli.group("nemo", cls=click.Group)
def nemo():
    """Nemo plugin for MLflow."""
    pass


@nemo.command()
@click.argument(
    "name",
    type=str,
    required=True,
)
@click.option(
    "--experiment-id",
    default=lambda: os.getenv("MLFLOW_EXPERIMENT_ID", None),
    show_default="MLFLOW_EXPERIMENT_ID (if set)",
    help="Experiment ID, taken from MLFLOW_EXPERIMENT_ID if not provided.",
)
def find(name: str, experiment_id: Optional[str]):
    """Find the run_id based on the run NAME."""
    if experiment_id is None:
        click.echo(
            "--experiment-id or MLFLOW_EXPERIMENT_ID is required .",
            err=True,
        )
        raise click.Abort()

    found_runs = find_run(run_name=name, experiment_id=experiment_id)
    for run in found_runs:
        click.echo(run)


if __name__ == "__main__":
    cli()



import os
from unittest.mock import patch

from click.testing import CliRunner

from mlflow.nemo.cli import find


def test_find_without_experiment_id():
    runner = CliRunner()
    result = runner.invoke(find, ["test_run"])
    assert result.exit_code == 1


def test_find_with_experiment_id(mlflow_experiment):
    runner = CliRunner()
    result = runner.invoke(find, ["test_run", "--experiment-id", "1"])
    assert result.exit_code == 0


def test_find_with_env_experiment_id(mlflow_experiment):
    runner = CliRunner()
    with patch.dict(os.environ, {"MLFLOW_EXPERIMENT_ID": "2"}):
        result = runner.invoke(find, ["test_run"])
    assert result.exit_code == 0
